@@ -1,4 +1,3 @@
-import importlib.metadata
 import shutil
 import tarfile
 import zipfile
@@ -8,7 +7,12 @@ from urllib.parse import urlparse
 import IPython
 from tqdm.auto import tqdm
 
-__version__ = importlib.metadata.version("skillsnetwork")
+try:
+    import importlib.metadata as importlib_metadata
+except ModuleNotFoundError:
+    import importlib_metadata
+__version__ = importlib_metadata.version("skillsnetwork")
+
 DEFAULT_CHUNK_SIZE = 8 << 10
 
 
@@ -145,7 +149,7 @@ async def prepare(url, path=None):
         # Is throw error the right thing?
         raise ValueError("path must not be in /tmp")
     # Create the target path if it doesn't exist yet
-    path.mkdir(parents=True, exist_ok=True)
+    path.mkdir(exist_ok=True)
 
     # For avoiding collisions with any other files the user may have downloaded to /tmp/
     tmp_extract_dir = Path(f"/tmp/skills-network-{hash(url)}")
